NOTE:
The context rules in this location were converted from provided resources from FastConText in this paper:

https://hal-lirmm.ccsd.cnrs.fr/lirmm-01656834/document

BIBTEX for this paper:
@inproceedings{abdaoui2017french,
  title={French ConText: D{\'e}tecter la n{\'e}gation, la temporalit{\'e} et le sujet dans les textes cliniques Fran{\c{c}}ais},
  author={Abdaoui, Amine and Tchechmedjiev, Andon and Digan, William and Bringay, Sandra and Jonquet, Clement},
  booktitle={SIIM 2017-4{\`e}me Symposium sur l'Ing{\'e}nierie de l'Information M{\'e}dicale},
  year={2017}
}

The rules originally came from here, and Alec B Chapman wrote a script to convert these for the medspacy context component:
https://github.com/ontoportal-lirmm/annotators/tree/master/sifr-bioportal-annotation-postannotations/src/main/resources

